@@ -39,7 +39,7 @@ __copyright__ = """
 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 """
 
-__version__ = "0.2.1"
+__version__ = "0.3.0"
 modname = "sphinx-toolbox"
 pypi_name = "sphinx-toolbox"
 import_name = "sphinx_toolbox"
@@ -51,10 +51,17 @@ github_username = "domdfcoding"
 web = github_url = "https://github.com/domdfcoding/sphinx-toolbox"
 repo_root = pathlib.Path(__file__).parent
 install_requires = (repo_root / "requirements.txt").read_text(encoding="utf-8").split('\n')
-extras_require = {'all': []}
+extras_require = {'testing': ['pygments', 'pytest>=6.0.0', 'pytest-regressions>=2.0.1'], 'all': ['pygments', 'pytest-regressions>=2.0.1', 'pytest>=6.0.0']}
 
 
 
+conda_description = """Box of handy tools for Sphinx.
+
+
+Before installing please ensure you have added the following channels: domdfcoding, conda-forge"""
+__all__.append("conda_description")
+
+
 project_urls = {
 		"Documentation": "https://sphinx-toolbox.readthedocs.io",
 		"Issue Tracker": f"{github_url}/issues",
