@@ -4,6 +4,9 @@
 """
 Functions for testing Sphinx extensions.
 
+.. extras-require:: testing
+	:__pkginfo__:
+
 .. seealso:: Sphinx's own ``testing`` library: https://github.com/sphinx-doc/sphinx/tree/3.x/sphinx/testing
 """
 #
@@ -61,12 +64,15 @@ from typing import Any, Callable, Dict, List, NamedTuple, Optional, Set, Tuple,
 
 # 3rd party
 import sphinx.application
+from bs4 import BeautifulSoup  # type: ignore
 from docutils import nodes
 from docutils.nodes import Node  # NOQA
 from docutils.nodes import Element, TextElement
 from docutils.parsers.rst import Directive, roles
 from docutils.transforms import Transform
+from domdf_python_tools.stringlist import StringList
 from pygments.lexer import Lexer  # type: ignore
+from pytest_regressions.file_regression import FileRegressionFixture  # type: ignore
 from sphinx.builders import Builder
 from sphinx.config import Config
 from sphinx.domains import Domain, Index
@@ -79,7 +85,7 @@ from sphinx.roles import XRefRole
 from sphinx.util import docutils
 from sphinx.util.typing import RoleFunction, TitleGetter
 
-__all__ = ["Sphinx", "run_setup", "RunSetupOutput"]
+__all__ = ["Sphinx", "run_setup", "RunSetupOutput", "remove_html_footer", "check_html_regression"]
 
 
 class FakeBuilder(Builder):
@@ -509,3 +515,65 @@ def run_setup(
 		docutils.additional_nodes = _additional_nodes
 
 	return RunSetupOutput(setup_ret, directives, roles, additional_nodes, app)
+
+
+def remove_html_footer(page: BeautifulSoup) -> BeautifulSoup:
+	"""
+	Remove the Sphinx footer from HTML pages.
+
+	The footer contains the Sphinx and theme versions and therefore changes between versions.
+	This can cause unwanted, false positive test failures.
+
+	:param page: The page to remove the footer from.
+
+	:return: The page without the footer.
+	"""
+
+	for div in page.select("div.footer"):
+		div.extract()
+
+	return page
+
+
+def remove_html_link_tags(page: BeautifulSoup) -> BeautifulSoup:
+	"""
+	Remove link tags from HTML pages.
+
+	These may vary between different versions of Sphinx and its extensions.
+	This can cause unwanted, false positive test failures.
+
+	:param page: The page to remove the link tags from.
+
+	:return: The page without the link tags.
+	"""
+
+	for div in page.select("head link"):
+		div.extract()
+
+	return page
+
+
+def check_html_regression(page: BeautifulSoup, file_regression: FileRegressionFixture):
+	"""
+	Check an HTML page generated by Sphinx for regressions,
+	using `pytest-regressions <https://pypi.org/project/pytest-regressions/>`_
+
+	:param page: The page to test.
+	:param file_regression: The file regression fixture.
+
+	**Example usage**
+
+	.. code-block:: python
+
+		@pytest.mark.parametrize("page", ["index.html"], indirect=True)
+		def test_page(page: BeautifulSoup, file_regression: FileRegressionFixture):
+			check_html_regression(page, file_regression)
+	"""
+
+	page = remove_html_footer(page)
+	page = remove_html_link_tags(page)
+	file_regression.check(
+			contents=str(StringList(page.prettify())),
+			extension=".html",
+			encoding="UTF-8",
+			)
